@@ -2,7 +2,7 @@
 
 from django.db import models
 
-from app.models import BaseModel
+from roiburo.models import BaseModel
 
 
 class SystemState(BaseModel):
