@@ -2,7 +2,7 @@
 
 from rest_framework import serializers
 
-from core.models import SystemState
+from roiburo.core.models import SystemState
 
 
 class SystemStateSzr(serializers.ModelSerializer):
